@@ -1,6 +1,6 @@
 /*
     This file is part of libkabc.
-    Copyright (c) 2015-2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -41,6 +41,7 @@ public:
         parameters = other.parameters;
         type = other.type;
     }
+
     QMap<QString, QStringList> parameters;
     QString address;
     ImppType type;
@@ -49,7 +50,6 @@ public:
 Impp::Impp()
     : d(new Private)
 {
-
 }
 
 Impp::Impp(const Impp &other)
@@ -65,7 +65,6 @@ Impp::Impp(const QString &address)
 
 Impp::~Impp()
 {
-
 }
 
 bool Impp::isValid() const
@@ -124,16 +123,16 @@ Impp &Impp::operator=(const Impp &other)
 
 QString Impp::toString() const
 {
-    QString str;
-    str += QLatin1String("Impp {\n");
+    QString str = QLatin1String("Impp {\n");
     str += QStringLiteral("    type: %1\n").arg(typeToString(d->type));
     str += QStringLiteral("    address: %1\n").arg(d->address);
     if (!d->parameters.isEmpty()) {
-        QMapIterator<QString, QStringList> i(d->parameters);
         QString param;
-        while (i.hasNext()) {
-            i.next();
-            param += QStringLiteral("%1 %2").arg(i.key(), i.value().join(QLatin1Char(',')));
+        QMap<QString, QStringList>::const_iterator it = d->parameters.constBegin();
+        const QMap<QString, QStringList>::const_iterator end = d->parameters.constEnd();
+        while (it != end) {
+            param += QStringLiteral("%1 %2").arg(it.key(), it.value().join(QLatin1Char(',')));
+            ++it;
         }
         str += QStringLiteral("    parameters: %1\n").arg(param);
     }
@@ -192,4 +191,3 @@ QDataStream &KContacts::operator>>(QDataStream &s, Impp &impp)
     impp.d->type = static_cast<Impp::ImppType>(i);
     return s;
 }
-
