@@ -27,9 +27,7 @@
 #include <kcontacts/addressee.h>
 #include <QMimeData>
 
-namespace KContacts
-{
-
+namespace KContacts {
 /**
   @brief Utility function for implementing drag&drop for vCards
 
@@ -37,9 +35,7 @@ namespace KContacts
 
   @since 4.5
 */
-namespace VCardDrag
-{
-
+namespace VCardDrag {
 /**
   Adds the vCard representation as data of the drag object.
 
@@ -96,7 +92,6 @@ KCONTACTS_EXPORT bool fromMimeData(const QMimeData *md, QByteArray &content);
 */
 KCONTACTS_EXPORT bool fromMimeData(const QMimeData *md, KContacts::Addressee::List &contacts);
 }
-
 }
 
 #endif // VCARDDRAG_H
